pub enum Proof {
Passkey(PasskeyProof),
Oauth(OAuthProof),
PasswordUnlock(PasswordUnlockCompletion),
}Variants
Passkey(PasskeyProof)
Oauth(OAuthProof)
PasswordUnlock(PasswordUnlockCompletion)
Requires owner admission and existing CallContext device-key PoP. All password completion failures use CALL_FAILURE_CODE_UNAUTHENTICATED.
Implementations
Sourceimpl Proof
impl Proof
Sourcepub fn merge(
field: &mut Option<Proof>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Proof>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.