pub enum Proof {
Attachment(RootAttachment),
BrowserPossession(SignedRecord),
}Expand description
Receiver-specific possession before credential release. Browser completion does not create an endpoint attachment or an independently trusted mint root.
Variants
Attachment(RootAttachment)
BrowserPossession(SignedRecord)
Implementations
Sourceimpl Proof
impl Proof
Sourcepub fn merge(
field: &mut Option<Proof>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Proof>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.