pub enum Owner {
EstablishOwner(OwnerRegistration),
ClaimOwner(SignedOwnerKeyTransition),
}Expand description
New signup establishes an owner root. Claim preserves the original deferred root and appends CLAIM_DEFERRED_HUMAN. Adding a passkey/device does not implicitly replace an existing owner root or change rooting tier.
Variants
EstablishOwner(OwnerRegistration)
ClaimOwner(SignedOwnerKeyTransition)
Implementations
Sourceimpl Owner
impl Owner
Sourcepub fn merge(
field: &mut Option<Owner>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Owner>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.