pub enum Entity {
Show 38 variants
Spool(SpoolRef),
Thread(ThreadRef),
Checkout(CheckoutRef),
Revision(RevisionRef),
Discussion(RecordRef),
Context(RecordRef),
Operation(RecordRef),
Run(RecordRef),
Policy(RecordRef),
Analysis(RecordRef),
Invitation(RecordRef),
Grant(RecordRef),
DiscussionTurn(RecordRef),
Review(RecordRef),
Notification(RecordRef),
AttentionItem(RecordRef),
Member(RecordRef),
ApprovalGroup(RecordRef),
Session(RecordRef),
SignupInvitation(RecordRef),
Device(EndpointRef),
TimelineEvent(RecordRef),
Artifact(RecordRef),
Bookmark(BookmarkRef),
Mount(RecordRef),
SupportAccess(RecordRef),
DeviceRecord(RecordRef),
Delegation(RecordRef),
Recovery(RecordRef),
OwnerTransition(RecordRef),
Billing(RecordRef),
Evidence(RecordRef),
CheckAcknowledgement(RecordRef),
ProviderConnection(RecordRef),
RemoteLink(RecordRef),
Passkey(RecordRef),
Principal(PrincipalRef),
Agent(AgentRef),
}Variants
Spool(SpoolRef)
Thread(ThreadRef)
Checkout(CheckoutRef)
Revision(RevisionRef)
Discussion(RecordRef)
Context(RecordRef)
Operation(RecordRef)
Run(RecordRef)
Policy(RecordRef)
Analysis(RecordRef)
Invitation(RecordRef)
Grant(RecordRef)
DiscussionTurn(RecordRef)
Review(RecordRef)
Notification(RecordRef)
AttentionItem(RecordRef)
Member(RecordRef)
ApprovalGroup(RecordRef)
Session(RecordRef)
SignupInvitation(RecordRef)
Device(EndpointRef)
TimelineEvent(RecordRef)
Artifact(RecordRef)
Bookmark(BookmarkRef)
Mount(RecordRef)
SupportAccess(RecordRef)
DeviceRecord(RecordRef)
Registry identity is distinct from the device’s transport locator.
Delegation(RecordRef)
Recovery(RecordRef)
OwnerTransition(RecordRef)
Billing(RecordRef)
Evidence(RecordRef)
CheckAcknowledgement(RecordRef)
ProviderConnection(RecordRef)
RemoteLink(RecordRef)
Passkey(RecordRef)
Principal(PrincipalRef)
Agent(AgentRef)
Implementations
Sourceimpl Entity
impl Entity
Sourcepub fn merge(
field: &mut Option<Entity>,
tag: u32,
wire_type: WireType,
buf: &mut impl Buf,
ctx: DecodeContext,
) -> Result<(), DecodeError>
pub fn merge( field: &mut Option<Entity>, tag: u32, wire_type: WireType, buf: &mut impl Buf, ctx: DecodeContext, ) -> Result<(), DecodeError>
Decodes an instance of the message from a buffer, and merges it into self.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.