#[repr(i32)]pub enum EvidenceCurrency {
Unspecified = 0,
Current = 1,
Stale = 2,
Failed = 3,
Missing = 4,
}Variants
Unspecified = 0
Current = 1
Passing, authorized evidence for the exact source revision.
Stale = 2
Previously passing evidence on recorded_revision, not this source.
Failed = 3
The current exact-source terminal result is failed, errored or skipped.
Missing = 4
No retained result available for this required check/source.
Implementations
Sourceimpl EvidenceCurrency
impl EvidenceCurrency
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EvidenceCurrency.
Sourcepub fn from_i32(value: i32) -> Option<EvidenceCurrency>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EvidenceCurrency>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EvidenceCurrency, or None if value is not a valid variant.
Sourceimpl EvidenceCurrency
impl EvidenceCurrency
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<EvidenceCurrency>
pub fn from_str_name(value: &str) -> Option<EvidenceCurrency>
Creates an enum from field names used in the ProtoBuf definition.