#[repr(i32)]pub enum ImportPreparationRefusalReason {
Unspecified = 0,
InvalidScope = 1,
UnsupportedConverter = 2,
UnsupportedOptions = 3,
BudgetExceeded = 4,
DestinationConflict = 5,
PolicyDenied = 6,
}Variants
Unspecified = 0
InvalidScope = 1
UnsupportedConverter = 2
UnsupportedOptions = 3
BudgetExceeded = 4
DestinationConflict = 5
Stale destination configuration/ownership/policy CAS, or a full ref/slot reserved by a non-terminal job in this spool. See refusal.field.
PolicyDenied = 6
Implementations
Sourceimpl ImportPreparationRefusalReason
impl ImportPreparationRefusalReason
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ImportPreparationRefusalReason.
Sourcepub fn from_i32(value: i32) -> Option<ImportPreparationRefusalReason>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ImportPreparationRefusalReason>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ImportPreparationRefusalReason, or None if value is not a valid variant.
Sourceimpl ImportPreparationRefusalReason
impl ImportPreparationRefusalReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<ImportPreparationRefusalReason>
pub fn from_str_name(value: &str) -> Option<ImportPreparationRefusalReason>
Creates an enum from field names used in the ProtoBuf definition.