#[repr(i32)]pub enum SearchMatchKind {
Unspecified = 0,
Exact = 1,
Prefix = 2,
Fuzzy = 3,
Fulltext = 4,
Semantic = 5,
HashExact = 6,
HashPrefix = 7,
Structured = 8,
}Expand description
How this match was established; score is only comparable within this query.
Variants
Unspecified = 0
Exact = 1
Prefix = 2
Fuzzy = 3
Fulltext = 4
Semantic = 5
HashExact = 6
HashPrefix = 7
Structured = 8
Implementations
Sourceimpl SearchMatchKind
impl SearchMatchKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SearchMatchKind>
pub fn from_str_name(value: &str) -> Option<SearchMatchKind>
Creates an enum from field names used in the ProtoBuf definition.