#[repr(i32)]pub enum SearchSourceHistory {
Unspecified = 0,
Current = 1,
Retained = 2,
}Expand description
Which accepted source revisions participate in content and symbol search.
Variants
Unspecified = 0
Current = 1
All concurrent source heads of each selected Thread. A withheld head does not fall back to an older visible revision.
Retained = 2
Implementations
Sourceimpl SearchSourceHistory
impl SearchSourceHistory
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SearchSourceHistory.
Sourcepub fn from_i32(value: i32) -> Option<SearchSourceHistory>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SearchSourceHistory>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SearchSourceHistory, or None if value is not a valid variant.
Sourceimpl SearchSourceHistory
impl SearchSourceHistory
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SearchSourceHistory>
pub fn from_str_name(value: &str) -> Option<SearchSourceHistory>
Creates an enum from field names used in the ProtoBuf definition.