#[repr(i32)]pub enum SourcePathKindSource {
Unspecified = 0,
Recorded = 1,
Derived = 2,
}Expand description
Read-projection provenance, never part of a canonical signed source map.
Variants
Implementations
Sourceimpl SourcePathKindSource
impl SourcePathKindSource
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of SourcePathKindSource.
Sourcepub fn from_i32(value: i32) -> Option<SourcePathKindSource>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<SourcePathKindSource>
Use the TryFrom<i32> implementation instead
Converts an i32 to a SourcePathKindSource, or None if value is not a valid variant.
Sourceimpl SourcePathKindSource
impl SourcePathKindSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SourcePathKindSource>
pub fn from_str_name(value: &str) -> Option<SourcePathKindSource>
Creates an enum from field names used in the ProtoBuf definition.