#[repr(i32)]pub enum SpoolSection {
Unspecified = 0,
Overview = 1,
Threads = 2,
Members = 3,
Invitations = 4,
Grants = 5,
Policies = 6,
Context = 7,
Operations = 8,
Children = 9,
SupportAccess = 10,
SignedPolicy = 11,
}Variants
Unspecified = 0
Overview = 1
Threads = 2
Members = 3
Invitations = 4
Grants = 5
Policies = 6
Context = 7
Operations = 8
Children = 9
SupportAccess = 10
SignedPolicy = 11
Complete signed-policy chain, sequence order. Member-gated like owner_genesis; not public on public spools. Replaces v1 GetOwnerGovernanceHead without a new RPC.
Implementations
Sourceimpl SpoolSection
impl SpoolSection
Sourceimpl SpoolSection
impl SpoolSection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<SpoolSection>
pub fn from_str_name(value: &str) -> Option<SpoolSection>
Creates an enum from field names used in the ProtoBuf definition.