#[repr(i32)]pub enum UploadTimelineEventKind {
Unspecified = 0,
RunStarted = 1,
TurnStarted = 2,
TurnFinished = 3,
ToolStarted = 4,
ToolFinished = 5,
PromptSubmitted = 6,
RunFinished = 7,
RunFailed = 8,
}Variants
Unspecified = 0
RunStarted = 1
TurnStarted = 2
TurnFinished = 3
ToolStarted = 4
ToolFinished = 5
PromptSubmitted = 6
RunFinished = 7
RunFailed = 8
Implementations
Sourceimpl UploadTimelineEventKind
impl UploadTimelineEventKind
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of UploadTimelineEventKind.
Sourcepub fn from_i32(value: i32) -> Option<UploadTimelineEventKind>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<UploadTimelineEventKind>
Use the TryFrom<i32> implementation instead
Converts an i32 to a UploadTimelineEventKind, or None if value is not a valid variant.
Sourceimpl UploadTimelineEventKind
impl UploadTimelineEventKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<UploadTimelineEventKind>
pub fn from_str_name(value: &str) -> Option<UploadTimelineEventKind>
Creates an enum from field names used in the ProtoBuf definition.