pub struct AnalysisRecord {
pub ref: Option<RecordRef>,
pub source: Option<RevisionRef>,
pub base: Option<RevisionRef>,
pub kind: i32,
pub analyzer: String,
pub analyzer_version: String,
pub coverage: i32,
pub operation: Option<RecordRef>,
pub version: Vec<u8>,
pub finding_count: Option<u64>,
pub thread: Option<ThreadRef>,
pub base_thread: Option<ThreadRef>,
}Fields
ref: Option<RecordRef>source: Option<RevisionRef>base: Option<RevisionRef>kind: i32analyzer: Stringanalyzer_version: Stringcoverage: i32operation: Option<RecordRef>version: Vec<u8>finding_count: Option<u64>Exact total only when known. A bounded/partial projection must not report the current page’s size as the total or use zero to mean unknown.
thread: Option<ThreadRef>base_thread: Option<ThreadRef>Exact base owner; absent only when this analysis has no base revision.
Implementations
Sourceimpl AnalysisRecord
impl AnalysisRecord
Sourcepub fn kind(&self) -> AnalysisKind
pub fn kind(&self) -> AnalysisKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: AnalysisKind)
pub fn set_kind(&mut self, value: AnalysisKind)
Sets kind to the provided enum value.
Sourcepub fn coverage(&self) -> Coverage
pub fn coverage(&self) -> Coverage
Returns the enum value of coverage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_coverage(&mut self, value: Coverage)
pub fn set_coverage(&mut self, value: Coverage)
Sets coverage to the provided enum value.
Sourcepub fn finding_count(&self) -> u64
pub fn finding_count(&self) -> u64
Returns the value of finding_count, or the default value if finding_count is unset.