pub struct BeginRecoveryRequest {
pub client_operation_id: String,
pub account_id: String,
pub proposed_root_public_key: Vec<u8>,
pub method_id: String,
pub account_handle: String,
}Fields
client_operation_id: Stringaccount_id: StringExactly one account selector is required. A lost device may know only the public native handle; both unknown selectors receive synthetic KDF data.
proposed_root_public_key: Vec<u8>method_id: Stringaccount_handle: StringTrait Implementations
Sourceimpl Clone for BeginRecoveryRequest
impl Clone for BeginRecoveryRequest
Sourcefn clone(&self) -> BeginRecoveryRequest
fn clone(&self) -> BeginRecoveryRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BeginRecoveryRequest
impl Debug for BeginRecoveryRequest
Sourceimpl Default for BeginRecoveryRequest
impl Default for BeginRecoveryRequest
Sourcefn default() -> BeginRecoveryRequest
fn default() -> BeginRecoveryRequest
Returns the “default value” for a type. Read more
impl Eq for BeginRecoveryRequest
Sourceimpl Hash for BeginRecoveryRequest
impl Hash for BeginRecoveryRequest
Sourceimpl Message for BeginRecoveryRequest
impl Message for BeginRecoveryRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BeginRecoveryRequest
impl PartialEq for BeginRecoveryRequest
impl StructuralPartialEq for BeginRecoveryRequest