pub struct BehaviorBranch {
pub id: String,
pub label: i32,
pub result_id: String,
pub source: Option<BehaviorSource>,
pub provenance: i32,
}Fields
id: Stringlabel: i32result_id: Stringsource: Option<BehaviorSource>provenance: i32Implementations
Sourceimpl BehaviorBranch
impl BehaviorBranch
Sourcepub fn label(&self) -> Label
pub fn label(&self) -> Label
Returns the enum value of label, or the default if the field is set to an invalid enum value.
Sourcepub fn provenance(&self) -> BehaviorProvenance
pub fn provenance(&self) -> BehaviorProvenance
Returns the enum value of provenance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provenance(&mut self, value: BehaviorProvenance)
pub fn set_provenance(&mut self, value: BehaviorProvenance)
Sets provenance to the provided enum value.