pub struct BehaviorCorrespondence {
pub id: String,
pub base_ids: Vec<String>,
pub source_ids: Vec<String>,
pub kind: i32,
pub reasons: Vec<i32>,
pub provenance: i32,
}Fields
id: Stringbase_ids: Vec<String>IDs refer to expressions/assignments in this record. A single old fact can participate in multiple correspondences. Ambiguous candidates are lists, never a guessed pairing. Empty side means added/removed.
source_ids: Vec<String>kind: i32reasons: Vec<i32>provenance: i32Implementations
Sourceimpl BehaviorCorrespondence
impl BehaviorCorrespondence
Sourcepub fn kind(&self) -> BehaviorCorrespondenceKind
pub fn kind(&self) -> BehaviorCorrespondenceKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: BehaviorCorrespondenceKind)
pub fn set_kind(&mut self, value: BehaviorCorrespondenceKind)
Sets kind to the provided enum value.
Sourcepub fn reasons(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<BehaviorMatchReason>> ⓘ
pub fn reasons( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<BehaviorMatchReason>> ⓘ
Returns an iterator which yields the valid enum values contained in reasons.
Sourcepub fn push_reasons(&mut self, value: BehaviorMatchReason)
pub fn push_reasons(&mut self, value: BehaviorMatchReason)
Appends the provided enum value to reasons.
Sourcepub fn provenance(&self) -> BehaviorProvenance
pub fn provenance(&self) -> BehaviorProvenance
Returns the enum value of provenance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provenance(&mut self, value: BehaviorProvenance)
pub fn set_provenance(&mut self, value: BehaviorProvenance)
Sets provenance to the provided enum value.