pub struct BehaviorDependencies {
pub base_extraction: Vec<u8>,
pub source_extraction: Vec<u8>,
pub base_bindings: Vec<u8>,
pub source_bindings: Vec<u8>,
pub comparison: Vec<u8>,
}Fields
base_extraction: Vec<u8>Extraction: exact blob bytes + grammar + symbol/expression versions. Binding: extraction + the complete containing lexical source, including declarations and writes. Comparison: both binding artifacts + comparison version + exact revision pair/path. Selection caches additionally bind query paths/symbols. Hashes are domain-separated.
source_extraction: Vec<u8>base_bindings: Vec<u8>source_bindings: Vec<u8>comparison: Vec<u8>Trait Implementations
Sourceimpl Clone for BehaviorDependencies
impl Clone for BehaviorDependencies
Sourcefn clone(&self) -> BehaviorDependencies
fn clone(&self) -> BehaviorDependencies
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorDependencies
impl Debug for BehaviorDependencies
Sourceimpl Default for BehaviorDependencies
impl Default for BehaviorDependencies
Sourcefn default() -> BehaviorDependencies
fn default() -> BehaviorDependencies
Returns the “default value” for a type. Read more
impl Eq for BehaviorDependencies
Sourceimpl Hash for BehaviorDependencies
impl Hash for BehaviorDependencies
Sourceimpl Message for BehaviorDependencies
impl Message for BehaviorDependencies
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BehaviorDependencies
impl PartialEq for BehaviorDependencies
impl StructuralPartialEq for BehaviorDependencies