pub struct BehaviorSource {
pub revision: Option<RevisionRef>,
pub path: String,
pub blob_hash: Vec<u8>,
pub start_byte: u32,
pub end_byte: u32,
pub text: String,
pub symbol_address: String,
}Expand description
Source navigation is pinned to bytes, never just a semantic digest. Byte offsets are zero-based, half-open UTF-8 byte ranges. No inferred locations.
Fields
revision: Option<RevisionRef>path: Stringblob_hash: Vec<u8>start_byte: u32end_byte: u32text: Stringsymbol_address: StringTrait Implementations
Sourceimpl Clone for BehaviorSource
impl Clone for BehaviorSource
Sourcefn clone(&self) -> BehaviorSource
fn clone(&self) -> BehaviorSource
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BehaviorSource
impl Debug for BehaviorSource
Sourceimpl Default for BehaviorSource
impl Default for BehaviorSource
Sourcefn default() -> BehaviorSource
fn default() -> BehaviorSource
Returns the “default value” for a type. Read more
impl Eq for BehaviorSource
Sourceimpl Hash for BehaviorSource
impl Hash for BehaviorSource
Sourceimpl Message for BehaviorSource
impl Message for BehaviorSource
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for BehaviorSource
impl PartialEq for BehaviorSource
impl StructuralPartialEq for BehaviorSource