pub struct BillingRecord {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub plan: String,
pub status: i32,
pub current_period_end: Option<Timestamp>,
pub cancel_at_period_end: Option<bool>,
pub seats: Option<u32>,
pub recurring_amount: Option<Money>,
pub actions: Vec<ActionAvailability>,
}Fields
ref: Option<RecordRef>version: Vec<u8>plan: Stringstatus: i32current_period_end: Option<Timestamp>cancel_at_period_end: Option<bool>Absent when the provider has not reported it.
seats: Option<u32>recurring_amount: Option<Money>actions: Vec<ActionAvailability>Coverage/status belongs to the observation section. Missing provider data must not be represented as a free plan or canceled subscription.
Implementations
Sourceimpl BillingRecord
impl BillingRecord
Sourcepub fn status(&self) -> SubscriptionStatus
pub fn status(&self) -> SubscriptionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: SubscriptionStatus)
pub fn set_status(&mut self, value: SubscriptionStatus)
Sets status to the provided enum value.
Sourcepub fn cancel_at_period_end(&self) -> bool
pub fn cancel_at_period_end(&self) -> bool
Returns the value of cancel_at_period_end, or the default value if cancel_at_period_end is unset.