pub struct BrowserPairingCompletionBinding {
pub host: Option<EndpointRef>,
pub client_operation_id: String,
pub pairing: Option<RecordRef>,
pub approval: Option<BrowserPairingApprovalBinding>,
}Expand description
SignedRecord format heddle.browser-pairing-completion.v1. The current subject key signs domain || deterministic protobuf bytes plus a fresh exact RPC proof.
Fields
host: Option<EndpointRef>client_operation_id: Stringpairing: Option<RecordRef>approval: Option<BrowserPairingApprovalBinding>Trait Implementations
Sourceimpl Clone for BrowserPairingCompletionBinding
impl Clone for BrowserPairingCompletionBinding
Sourcefn clone(&self) -> BrowserPairingCompletionBinding
fn clone(&self) -> BrowserPairingCompletionBinding
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for BrowserPairingCompletionBinding
impl Default for BrowserPairingCompletionBinding
Sourcefn default() -> BrowserPairingCompletionBinding
fn default() -> BrowserPairingCompletionBinding
Returns the “default value” for a type. Read more
impl Eq for BrowserPairingCompletionBinding
Sourceimpl Message for BrowserPairingCompletionBinding
impl Message for BrowserPairingCompletionBinding
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for BrowserPairingCompletionBinding