pub struct CatalogEvent {
pub frame: Option<StreamFrame>,
pub payload: Option<Payload>,
}Fields
frame: Option<StreamFrame>payload: Option<Payload>Trait Implementations
Sourceimpl Clone for CatalogEvent
impl Clone for CatalogEvent
Sourcefn clone(&self) -> CatalogEvent
fn clone(&self) -> CatalogEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CatalogEvent
impl Debug for CatalogEvent
Sourceimpl Default for CatalogEvent
impl Default for CatalogEvent
Sourcefn default() -> CatalogEvent
fn default() -> CatalogEvent
Returns the “default value” for a type. Read more
Sourceimpl Message for CatalogEvent
impl Message for CatalogEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl ObservedEvent for CatalogEvent
impl ObservedEvent for CatalogEvent
type Payload = Payload
fn frame(&self) -> Option<&StreamFrame>
fn has_payload(&self) -> bool
fn take_payload(&mut self) -> Option<<CatalogEvent as ObservedEvent>::Payload>
fn is_removal(&self) -> bool
Sourceimpl PartialEq for CatalogEvent
impl PartialEq for CatalogEvent
impl StructuralPartialEq for CatalogEvent