pub struct CheckAcknowledgementRecord {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub evidence: Option<RecordRef>,
pub revision: Option<RevisionRef>,
pub policy_version: Vec<u8>,
pub author: Option<PrincipalRef>,
pub agent_id: String,
pub acknowledged_at: Option<Timestamp>,
pub acknowledgement: Option<SignedRecord>,
}Expand description
Immutable review progress for one accepted check result and exact policy. This does not change its outcome, supersede evidence or grant landing approval.
Fields
ref: Option<RecordRef>version: Vec<u8>evidence: Option<RecordRef>revision: Option<RevisionRef>policy_version: Vec<u8>agent_id: Stringacknowledged_at: Option<Timestamp>acknowledgement: Option<SignedRecord>Trait Implementations
Sourceimpl Clone for CheckAcknowledgementRecord
impl Clone for CheckAcknowledgementRecord
Sourcefn clone(&self) -> CheckAcknowledgementRecord
fn clone(&self) -> CheckAcknowledgementRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckAcknowledgementRecord
impl Debug for CheckAcknowledgementRecord
Sourceimpl Default for CheckAcknowledgementRecord
impl Default for CheckAcknowledgementRecord
Sourcefn default() -> CheckAcknowledgementRecord
fn default() -> CheckAcknowledgementRecord
Returns the “default value” for a type. Read more
Sourceimpl Message for CheckAcknowledgementRecord
impl Message for CheckAcknowledgementRecord
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for CheckAcknowledgementRecord