pub struct CheckoutEvent {
pub frame: Option<StreamFrame>,
pub payload: Option<Payload>,
}Fields
frame: Option<StreamFrame>payload: Option<Payload>Trait Implementations
Sourceimpl Clone for CheckoutEvent
impl Clone for CheckoutEvent
Sourcefn clone(&self) -> CheckoutEvent
fn clone(&self) -> CheckoutEvent
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckoutEvent
impl Debug for CheckoutEvent
Sourceimpl Default for CheckoutEvent
impl Default for CheckoutEvent
Sourcefn default() -> CheckoutEvent
fn default() -> CheckoutEvent
Returns the “default value” for a type. Read more
Sourceimpl Message for CheckoutEvent
impl Message for CheckoutEvent
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl ObservedEvent for CheckoutEvent
impl ObservedEvent for CheckoutEvent
type Payload = Payload
fn frame(&self) -> Option<&StreamFrame>
fn has_payload(&self) -> bool
fn take_payload(&mut self) -> Option<<CheckoutEvent as ObservedEvent>::Payload>
fn is_removal(&self) -> bool
Sourceimpl PartialEq for CheckoutEvent
impl PartialEq for CheckoutEvent
impl StructuralPartialEq for CheckoutEvent