pub struct CheckoutWriterLease {
pub checkout: Option<CheckoutRef>,
pub token: Vec<u8>,
pub actor_session_id: String,
pub expires_at: Option<Timestamp>,
}Expand description
The same physical-checkout lease is enforced by CLI and device RPCs. Possessing its token never grants authority: each mutation also authenticates the owner session, verifies current capability, and compares source/version.
Fields
checkout: Option<CheckoutRef>token: Vec<u8>actor_session_id: Stringexpires_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for CheckoutWriterLease
impl Clone for CheckoutWriterLease
Sourcefn clone(&self) -> CheckoutWriterLease
fn clone(&self) -> CheckoutWriterLease
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckoutWriterLease
impl Debug for CheckoutWriterLease
Sourceimpl Default for CheckoutWriterLease
impl Default for CheckoutWriterLease
Sourcefn default() -> CheckoutWriterLease
fn default() -> CheckoutWriterLease
Returns the “default value” for a type. Read more
impl Eq for CheckoutWriterLease
Sourceimpl Hash for CheckoutWriterLease
impl Hash for CheckoutWriterLease
Sourceimpl Message for CheckoutWriterLease
impl Message for CheckoutWriterLease
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CheckoutWriterLease
impl PartialEq for CheckoutWriterLease
impl StructuralPartialEq for CheckoutWriterLease