pub struct ClientOwnedCredential {
pub ref: Option<RecordRef>,
pub subject: String,
pub proof_public_key: Vec<u8>,
pub kind: i32,
}Fields
ref: Option<RecordRef>subject: StringExact verified credential subject, distinct from the human account UUID.
proof_public_key: Vec<u8>kind: i32Implementations
Sourceimpl ClientOwnedCredential
impl ClientOwnedCredential
Sourcepub fn kind(&self) -> CredentialKind
pub fn kind(&self) -> CredentialKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: CredentialKind)
pub fn set_kind(&mut self, value: CredentialKind)
Sets kind to the provided enum value.