pub struct DecideRunPermissionRequest {
pub client_operation_id: String,
pub run: Option<RecordRef>,
pub permission_id: String,
pub request_digest: Vec<u8>,
pub allow: bool,
}Fields
client_operation_id: Stringrun: Option<RecordRef>permission_id: Stringrequest_digest: Vec<u8>allow: boolTrait Implementations
Sourceimpl Clone for DecideRunPermissionRequest
impl Clone for DecideRunPermissionRequest
Sourcefn clone(&self) -> DecideRunPermissionRequest
fn clone(&self) -> DecideRunPermissionRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecideRunPermissionRequest
impl Debug for DecideRunPermissionRequest
Sourceimpl Default for DecideRunPermissionRequest
impl Default for DecideRunPermissionRequest
Sourcefn default() -> DecideRunPermissionRequest
fn default() -> DecideRunPermissionRequest
Returns the “default value” for a type. Read more
impl Eq for DecideRunPermissionRequest
Sourceimpl Hash for DecideRunPermissionRequest
impl Hash for DecideRunPermissionRequest
Sourceimpl Message for DecideRunPermissionRequest
impl Message for DecideRunPermissionRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for DecideRunPermissionRequest