pub struct DeleteAccountRequest {
pub client_operation_id: String,
pub confirmation_handle: String,
}Expand description
Irreversibly deletes the caller’s account. The authenticating credential MUST be the direct account owner’s proof-bearing credential: agent, service, delegated, derived and attenuated credentials are rejected even if they otherwise carry caller-bound account authority. confirmation_handle MUST exactly equal the account’s current handle. Reusing client_operation_id returns the original outcome without deleting or canceling anything twice.
Fields
client_operation_id: Stringconfirmation_handle: StringTrait Implementations
Sourceimpl Clone for DeleteAccountRequest
impl Clone for DeleteAccountRequest
Sourcefn clone(&self) -> DeleteAccountRequest
fn clone(&self) -> DeleteAccountRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeleteAccountRequest
impl Debug for DeleteAccountRequest
Sourceimpl Default for DeleteAccountRequest
impl Default for DeleteAccountRequest
Sourcefn default() -> DeleteAccountRequest
fn default() -> DeleteAccountRequest
Returns the “default value” for a type. Read more
impl Eq for DeleteAccountRequest
Sourceimpl Hash for DeleteAccountRequest
impl Hash for DeleteAccountRequest
Sourceimpl Message for DeleteAccountRequest
impl Message for DeleteAccountRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DeleteAccountRequest
impl PartialEq for DeleteAccountRequest
impl StructuralPartialEq for DeleteAccountRequest