pub struct DescribeEndpointResponse {
pub endpoint: Option<EndpointRef>,
pub supported_packages: Vec<String>,
pub implemented_methods: Vec<String>,
pub understood_signed_record_formats: Vec<String>,
pub default_read_budget: Option<ReadBudget>,
pub maximum_read_budget: Option<ReadBudget>,
pub max_concurrent_streams_per_connection: u32,
pub max_pending_batch_bytes: u32,
pub max_cursor_bytes: u32,
pub operation_deduplication_retention_seconds: u64,
pub portable_root_attachment_verification: bool,
}Fields
endpoint: Option<EndpointRef>supported_packages: Vec<String>implemented_methods: Vec<String>Implemented handlers only. Compiled descriptors and PLANNED routes cannot populate this list automatically. Availability does not imply permission.
understood_signed_record_formats: Vec<String>default_read_budget: Option<ReadBudget>maximum_read_budget: Option<ReadBudget>max_concurrent_streams_per_connection: u32max_pending_batch_bytes: u32max_cursor_bytes: u32operation_deduplication_retention_seconds: u64portable_root_attachment_verification: boolTrait Implementations
Sourceimpl Clone for DescribeEndpointResponse
impl Clone for DescribeEndpointResponse
Sourcefn clone(&self) -> DescribeEndpointResponse
fn clone(&self) -> DescribeEndpointResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DescribeEndpointResponse
impl Debug for DescribeEndpointResponse
Sourceimpl Default for DescribeEndpointResponse
impl Default for DescribeEndpointResponse
Sourcefn default() -> DescribeEndpointResponse
fn default() -> DescribeEndpointResponse
Returns the “default value” for a type. Read more
impl Eq for DescribeEndpointResponse
Sourceimpl Hash for DescribeEndpointResponse
impl Hash for DescribeEndpointResponse
Sourceimpl Message for DescribeEndpointResponse
impl Message for DescribeEndpointResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DescribeEndpointResponse
impl PartialEq for DescribeEndpointResponse
impl StructuralPartialEq for DescribeEndpointResponse