pub struct DiscussionTurn {
pub ref: Option<RecordRef>,
pub discussion: Option<RecordRef>,
pub body: String,
pub principal_id: String,
pub agent_id: String,
pub mentions: Vec<EntityRef>,
pub created_at: Option<Timestamp>,
pub causal_id: Vec<u8>,
pub causal_parents: Vec<Vec<u8>>,
}Fields
ref: Option<RecordRef>discussion: Option<RecordRef>body: Stringprincipal_id: Stringagent_id: Stringmentions: Vec<EntityRef>created_at: Option<Timestamp>causal_id: Vec<u8>Immutable replication-operation identity and dependencies, shared across replicas. These are separate from the addressable record ID and mutable view version.
causal_parents: Vec<Vec<u8>>Trait Implementations
Sourceimpl Clone for DiscussionTurn
impl Clone for DiscussionTurn
Sourcefn clone(&self) -> DiscussionTurn
fn clone(&self) -> DiscussionTurn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DiscussionTurn
impl Debug for DiscussionTurn
Sourceimpl Default for DiscussionTurn
impl Default for DiscussionTurn
Sourcefn default() -> DiscussionTurn
fn default() -> DiscussionTurn
Returns the “default value” for a type. Read more
Sourceimpl Message for DiscussionTurn
impl Message for DiscussionTurn
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for DiscussionTurn
impl PartialEq for DiscussionTurn
impl StructuralPartialEq for DiscussionTurn