pub struct EndpointRef {
pub public_key: Vec<u8>,
pub kind: i32,
}Fields
public_key: Vec<u8>Stable Iroh endpoint public key, exactly 32 bytes. Never a relay address.
kind: i32Implementations
Sourceimpl EndpointRef
impl EndpointRef
Sourcepub fn kind(&self) -> EndpointKind
pub fn kind(&self) -> EndpointKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: EndpointKind)
pub fn set_kind(&mut self, value: EndpointKind)
Sets kind to the provided enum value.