pub struct ImportOwnerChainV1 {
pub spool_genesis_digest: Vec<u8>,
pub owner_state_hashes: Vec<Vec<u8>>,
pub transfer_audit_hashes: Vec<Vec<u8>>,
}Expand description
Recomputed from independently verified owner histories and handoff audits, not an incoming digest. State hashes are sorted unique, transfer hashes are in accepted sequence order. The histories retain every original signature.
Fields
spool_genesis_digest: Vec<u8>owner_state_hashes: Vec<Vec<u8>>transfer_audit_hashes: Vec<Vec<u8>>Trait Implementations
Sourceimpl Canonical for ImportOwnerChainV1
impl Canonical for ImportOwnerChainV1
Sourceimpl Clone for ImportOwnerChainV1
impl Clone for ImportOwnerChainV1
Sourcefn clone(&self) -> ImportOwnerChainV1
fn clone(&self) -> ImportOwnerChainV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportOwnerChainV1
impl Debug for ImportOwnerChainV1
Sourceimpl Default for ImportOwnerChainV1
impl Default for ImportOwnerChainV1
Sourcefn default() -> ImportOwnerChainV1
fn default() -> ImportOwnerChainV1
Returns the “default value” for a type. Read more
impl Eq for ImportOwnerChainV1
Sourceimpl Hash for ImportOwnerChainV1
impl Hash for ImportOwnerChainV1
Sourceimpl Message for ImportOwnerChainV1
impl Message for ImportOwnerChainV1
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ImportOwnerChainV1
impl PartialEq for ImportOwnerChainV1
impl StructuralPartialEq for ImportOwnerChainV1