pub struct ImportProviderConfigurationV1 {
pub provider: String,
pub source_modes: Vec<i32>,
}Fields
provider: StringLaunch registry: github -> CONNECTED; public-git -> PUBLIC_HTTPS. gitlab is reserved for a future connected adapter and is not advertised.
source_modes: Vec<i32>Exactly the registered mode.
Implementations
Sourceimpl ImportProviderConfigurationV1
impl ImportProviderConfigurationV1
Sourcepub fn source_modes(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ImportSourceMode>> ⓘ
pub fn source_modes( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<ImportSourceMode>> ⓘ
Returns an iterator which yields the valid enum values contained in source_modes.
Sourcepub fn push_source_modes(&mut self, value: ImportSourceMode)
pub fn push_source_modes(&mut self, value: ImportSourceMode)
Appends the provided enum value to source_modes.