pub struct InvitationRecord {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub recipient: String,
pub role: i32,
pub expires_at: Option<Timestamp>,
pub revoked: bool,
pub redeemed: bool,
}Fields
ref: Option<RecordRef>version: Vec<u8>recipient: Stringrole: i32expires_at: Option<Timestamp>revoked: boolredeemed: boolRedemption secrets are returned only by CreateInvitation, never observations. This record has no include_descendants field. Redeeming MUST preserve an existing GrantRecord.include_descendants bit on conflict.
Implementations
Sourceimpl InvitationRecord
impl InvitationRecord
Sourcepub fn role(&self) -> ResourceRole
pub fn role(&self) -> ResourceRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: ResourceRole)
pub fn set_role(&mut self, value: ResourceRole)
Sets role to the provided enum value.