pub struct LandingAssessment {
pub target: Option<ThreadRef>,
pub source: Option<RevisionRef>,
pub expected_target: Option<RevisionRef>,
pub policy_version: Vec<u8>,
pub readiness: i32,
pub requirements: Vec<Requirement>,
}Fields
target: Option<ThreadRef>source: Option<RevisionRef>expected_target: Option<RevisionRef>policy_version: Vec<u8>readiness: i32requirements: Vec<Requirement>Implementations
Sourceimpl LandingAssessment
impl LandingAssessment
Sourcepub fn readiness(&self) -> ReviewReadiness
pub fn readiness(&self) -> ReviewReadiness
Returns the enum value of readiness, or the default if the field is set to an invalid enum value.
Sourcepub fn set_readiness(&mut self, value: ReviewReadiness)
pub fn set_readiness(&mut self, value: ReviewReadiness)
Sets readiness to the provided enum value.