pub struct MemberRecord {
pub ref: Option<RecordRef>,
pub principal_id: String,
pub role: i32,
pub version: Vec<u8>,
pub principal: Option<PublicPrincipalSummary>,
}Fields
ref: Option<RecordRef>principal_id: Stringrole: i32version: Vec<u8>principal: Option<PublicPrincipalSummary>When present, id must equal principal_id; absent means display unavailable.
Implementations
Sourceimpl MemberRecord
impl MemberRecord
Sourcepub fn role(&self) -> ResourceRole
pub fn role(&self) -> ResourceRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: ResourceRole)
pub fn set_role(&mut self, value: ResourceRole)
Sets role to the provided enum value.