pub struct MintRootAttachment {
pub format_version: u32,
pub account_uuid: Vec<u8>,
pub owner_state_hash: Vec<u8>,
pub owner_sequence: u64,
pub owner_key: Option<AuthorizationVerificationKey>,
pub mint_root_key: Option<AuthorizationVerificationKey>,
pub not_before_unix_seconds: i64,
pub expires_at_unix_seconds: i64,
pub nonce: Vec<u8>,
}Expand description
Public association of a credential mint root with one exact owner authority state. This grants no operations: ordinary Biscuit checks remain mandatory. Canonical v1 fields follow tag order using fixed-width/length-prefixed encoding. Domain: “heddle-mint-root-attachment-v1”.
Fields
format_version: u32account_uuid: Vec<u8>owner_state_hash: Vec<u8>owner_sequence: u64owner_key: Option<AuthorizationVerificationKey>mint_root_key: Option<AuthorizationVerificationKey>not_before_unix_seconds: i64expires_at_unix_seconds: i64nonce: Vec<u8>Trait Implementations
Sourceimpl Clone for MintRootAttachment
impl Clone for MintRootAttachment
Sourcefn clone(&self) -> MintRootAttachment
fn clone(&self) -> MintRootAttachment
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MintRootAttachment
impl Debug for MintRootAttachment
Sourceimpl Default for MintRootAttachment
impl Default for MintRootAttachment
Sourcefn default() -> MintRootAttachment
fn default() -> MintRootAttachment
Returns the “default value” for a type. Read more
impl Eq for MintRootAttachment
Sourceimpl Hash for MintRootAttachment
impl Hash for MintRootAttachment
Sourceimpl Message for MintRootAttachment
impl Message for MintRootAttachment
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for MintRootAttachment
impl PartialEq for MintRootAttachment
impl StructuralPartialEq for MintRootAttachment