pub struct NativeGenesisWitnessV1 {
pub format_version: u32,
pub kind: i32,
pub binding: Option<SignedNativeGenesisAuthorityV1>,
pub original_genesis: Option<SignedRecord>,
pub creator_authority_envelope: Vec<u8>,
pub boundary_acceptance: Option<ImportBoundaryAcceptanceV1>,
}Fields
format_version: u32kind: i32binding: Option<SignedNativeGenesisAuthorityV1>original_genesis: Option<SignedRecord>boundary_acceptance: Option<ImportBoundaryAcceptanceV1>Implementations
Sourceimpl NativeGenesisWitnessV1
impl NativeGenesisWitnessV1
Sourcepub fn kind(&self) -> NativeGenesisPayloadKind
pub fn kind(&self) -> NativeGenesisPayloadKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: NativeGenesisPayloadKind)
pub fn set_kind(&mut self, value: NativeGenesisPayloadKind)
Sets kind to the provided enum value.