pub struct ObserveAnalysisRequest {
pub source: Option<RevisionRef>,
pub base: Option<RevisionRef>,
pub kinds: Vec<i32>,
pub paths: Vec<String>,
pub page: Option<PageRequest>,
pub observe: Option<ObserveOptions>,
pub symbols: Vec<String>,
pub thread: Option<ThreadRef>,
pub base_thread: Option<ThreadRef>,
}Fields
source: Option<RevisionRef>base: Option<RevisionRef>kinds: Vec<i32>paths: Vec<String>page: Option<PageRequest>observe: Option<ObserveOptions>symbols: Vec<String>Exact qualified symbol addresses; empty selects all symbols in paths.
thread: Option<ThreadRef>Required owning Thread of source. A shared revision does not grant access through another Thread. Its Spool must match source.spool.
base_thread: Option<ThreadRef>Absent uses thread. An explicit comparison Thread is independently read.
Implementations
Sourceimpl ObserveAnalysisRequest
impl ObserveAnalysisRequest
Sourcepub fn kinds(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AnalysisKind>> ⓘ
pub fn kinds( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<AnalysisKind>> ⓘ
Returns an iterator which yields the valid enum values contained in kinds.
Sourcepub fn push_kinds(&mut self, value: AnalysisKind)
pub fn push_kinds(&mut self, value: AnalysisKind)
Appends the provided enum value to kinds.