pub struct ObserveCheckoutsRequest {
pub spool: Option<SpoolRef>,
pub threads: Vec<ThreadRef>,
pub checkouts: Vec<CheckoutRef>,
pub page: Option<PageRequest>,
pub observe: Option<ObserveOptions>,
}Fields
spool: Option<SpoolRef>threads: Vec<ThreadRef>checkouts: Vec<CheckoutRef>page: Option<PageRequest>observe: Option<ObserveOptions>Trait Implementations
Sourceimpl Clone for ObserveCheckoutsRequest
impl Clone for ObserveCheckoutsRequest
Sourcefn clone(&self) -> ObserveCheckoutsRequest
fn clone(&self) -> ObserveCheckoutsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObserveCheckoutsRequest
impl Debug for ObserveCheckoutsRequest
Sourceimpl Default for ObserveCheckoutsRequest
impl Default for ObserveCheckoutsRequest
Sourcefn default() -> ObserveCheckoutsRequest
fn default() -> ObserveCheckoutsRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ObserveCheckoutsRequest
impl Message for ObserveCheckoutsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl ObservationRequest for ObserveCheckoutsRequest
impl ObservationRequest for ObserveCheckoutsRequest
fn options_mut(&mut self) -> &mut ObserveOptions
Sourceimpl PartialEq for ObserveCheckoutsRequest
impl PartialEq for ObserveCheckoutsRequest
impl StructuralPartialEq for ObserveCheckoutsRequest