pub struct ObserveNotificationsRequest {
pub unread_only: bool,
pub include_preferences: bool,
pub page: Option<PageRequest>,
pub observe: Option<ObserveOptions>,
}Fields
unread_only: boolinclude_preferences: boolpage: Option<PageRequest>observe: Option<ObserveOptions>Trait Implementations
Sourceimpl Clone for ObserveNotificationsRequest
impl Clone for ObserveNotificationsRequest
Sourcefn clone(&self) -> ObserveNotificationsRequest
fn clone(&self) -> ObserveNotificationsRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ObserveNotificationsRequest
impl Debug for ObserveNotificationsRequest
Sourceimpl Default for ObserveNotificationsRequest
impl Default for ObserveNotificationsRequest
Sourcefn default() -> ObserveNotificationsRequest
fn default() -> ObserveNotificationsRequest
Returns the “default value” for a type. Read more
impl Eq for ObserveNotificationsRequest
Sourceimpl Hash for ObserveNotificationsRequest
impl Hash for ObserveNotificationsRequest
Sourceimpl Message for ObserveNotificationsRequest
impl Message for ObserveNotificationsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl ObservationRequest for ObserveNotificationsRequest
impl ObservationRequest for ObserveNotificationsRequest
fn options_mut(&mut self) -> &mut ObserveOptions
impl StructuralPartialEq for ObserveNotificationsRequest