pub struct ObserveSpoolRequest {
pub spool: Option<SpoolRef>,
pub sections: Vec<i32>,
pub threads: Option<ThreadQuery>,
pub pages: Option<SpoolPages>,
pub observe: Option<ObserveOptions>,
}Fields
spool: Option<SpoolRef>sections: Vec<i32>threads: Option<ThreadQuery>pages: Option<SpoolPages>observe: Option<ObserveOptions>Each requested administration section is independently authorized and paginated. SectionStatus distinguishes not requested from unavailable. SPOOL_SECTION_SIGNED_POLICY is member-gated (not public on public spools) and MUST return the complete chain in sequence order.
Implementations
Sourceimpl ObserveSpoolRequest
impl ObserveSpoolRequest
Sourcepub fn sections(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SpoolSection>> ⓘ
pub fn sections( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<SpoolSection>> ⓘ
Returns an iterator which yields the valid enum values contained in sections.
Sourcepub fn push_sections(&mut self, value: SpoolSection)
pub fn push_sections(&mut self, value: SpoolSection)
Appends the provided enum value to sections.