pub struct PrepareAccountClaimRequest {
pub client_operation_id: String,
pub browser_public_key: Vec<u8>,
pub handle: String,
pub claim_authorization: Vec<u8>,
}Expand description
Device-local consent for claiming an agent-rooted human account. Browser possession and the explicit claim authorization are both required. Weft independently verifies the registration; the device never submits it.
Fields
client_operation_id: Stringbrowser_public_key: Vec<u8>handle: StringTrait Implementations
Sourceimpl Clone for PrepareAccountClaimRequest
impl Clone for PrepareAccountClaimRequest
Sourcefn clone(&self) -> PrepareAccountClaimRequest
fn clone(&self) -> PrepareAccountClaimRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PrepareAccountClaimRequest
impl Debug for PrepareAccountClaimRequest
Sourceimpl Default for PrepareAccountClaimRequest
impl Default for PrepareAccountClaimRequest
Sourcefn default() -> PrepareAccountClaimRequest
fn default() -> PrepareAccountClaimRequest
Returns the “default value” for a type. Read more
impl Eq for PrepareAccountClaimRequest
Sourceimpl Hash for PrepareAccountClaimRequest
impl Hash for PrepareAccountClaimRequest
Sourceimpl Message for PrepareAccountClaimRequest
impl Message for PrepareAccountClaimRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for PrepareAccountClaimRequest