pub struct PrincipalRecord {Show 13 fields
pub id: String,
pub handle: String,
pub version: Vec<u8>,
pub root_public_key: Vec<u8>,
pub attachments: Vec<RootAttachment>,
pub account_id: String,
pub acting_agent_id: String,
pub authorized_resources: Vec<EntityRef>,
pub actions: Vec<ActionAvailability>,
pub entitlement: Option<EntitlementRecord>,
pub rooting_tier: i32,
pub display_name: String,
pub personal_spool: Option<SpoolAddress>,
}Fields
id: Stringhandle: Stringversion: Vec<u8>root_public_key: Vec<u8>attachments: Vec<RootAttachment>account_id: Stringacting_agent_id: Stringactions: Vec<ActionAvailability>entitlement: Option<EntitlementRecord>rooting_tier: i32display_name: StringGenerated pet name while agent-rooted and unclaimed; handle stays empty.
personal_spool: Option<SpoolAddress>Personal namespace for creation and remote provisioning. Omitted when it has not been created or is unavailable to this observing credential.
Implementations
Sourceimpl PrincipalRecord
impl PrincipalRecord
Sourcepub fn rooting_tier(&self) -> RootingTier
pub fn rooting_tier(&self) -> RootingTier
Returns the enum value of rooting_tier, or the default if the field is set to an invalid enum value.
Sourcepub fn set_rooting_tier(&mut self, value: RootingTier)
pub fn set_rooting_tier(&mut self, value: RootingTier)
Sets rooting_tier to the provided enum value.