pub struct PromoteSpoolRequest {
pub client_operation_id: String,
pub spool: Option<SpoolRef>,
pub expected_version: Vec<u8>,
}Expand description
Move a personal-root child to the account’s root-level address at its current slug. UUID, genesis, descendants, and direct grants survive. Bound by the destination ancestry’s effective max_audience: refuse promotion that would place a too-wide child under a tighter destination. Birth-parent lock does not follow the promoted spool.
Fields
client_operation_id: Stringspool: Option<SpoolRef>expected_version: Vec<u8>Trait Implementations
Sourceimpl Clone for PromoteSpoolRequest
impl Clone for PromoteSpoolRequest
Sourcefn clone(&self) -> PromoteSpoolRequest
fn clone(&self) -> PromoteSpoolRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PromoteSpoolRequest
impl Debug for PromoteSpoolRequest
Sourceimpl Default for PromoteSpoolRequest
impl Default for PromoteSpoolRequest
Sourcefn default() -> PromoteSpoolRequest
fn default() -> PromoteSpoolRequest
Returns the “default value” for a type. Read more
impl Eq for PromoteSpoolRequest
Sourceimpl Hash for PromoteSpoolRequest
impl Hash for PromoteSpoolRequest
Sourceimpl Message for PromoteSpoolRequest
impl Message for PromoteSpoolRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for PromoteSpoolRequest
impl PartialEq for PromoteSpoolRequest
impl StructuralPartialEq for PromoteSpoolRequest