pub struct ProposedHumanAction {
pub method: String,
pub canonical_request: Vec<u8>,
pub request_digest: Vec<u8>,
pub client_operation_id: String,
pub targets: Vec<EntityRef>,
pub request_proof: Option<RequestProof>,
pub human_verification: Option<HumanVerification>,
}Fields
method: Stringcanonical_request: Vec<u8>Exact deterministic protobuf request. Preserve bytes across older clients; unknown methods/critical semantics cannot be approved by an unaware client.
request_digest: Vec<u8>client_operation_id: Stringtargets: Vec<EntityRef>request_proof: Option<RequestProof>human_verification: Option<HumanVerification>Trait Implementations
Sourceimpl Clone for ProposedHumanAction
impl Clone for ProposedHumanAction
Sourcefn clone(&self) -> ProposedHumanAction
fn clone(&self) -> ProposedHumanAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProposedHumanAction
impl Debug for ProposedHumanAction
Sourceimpl Default for ProposedHumanAction
impl Default for ProposedHumanAction
Sourcefn default() -> ProposedHumanAction
fn default() -> ProposedHumanAction
Returns the “default value” for a type. Read more
Sourceimpl Message for ProposedHumanAction
impl Message for ProposedHumanAction
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProposedHumanAction
impl PartialEq for ProposedHumanAction
impl StructuralPartialEq for ProposedHumanAction