pub struct ProviderAssemblyRecord {
pub object: Option<TransferObject>,
pub encoded_length: u64,
pub encoded_digest: Option<ObjectAddress>,
pub output_offset: u64,
pub source: Option<Source>,
}Expand description
One record in output-pack order. Provider bytes must occupy an exact tiled physical range; inline bytes arrive as bounded ProviderInlineChunk frames. In either case the client verifies the encoded bytes and decoded object.
Fields
object: Option<TransferObject>encoded_length: u64encoded_digest: Option<ObjectAddress>output_offset: u64source: Option<Source>Trait Implementations
Sourceimpl Clone for ProviderAssemblyRecord
impl Clone for ProviderAssemblyRecord
Sourcefn clone(&self) -> ProviderAssemblyRecord
fn clone(&self) -> ProviderAssemblyRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderAssemblyRecord
impl Debug for ProviderAssemblyRecord
Sourceimpl Default for ProviderAssemblyRecord
impl Default for ProviderAssemblyRecord
Sourcefn default() -> ProviderAssemblyRecord
fn default() -> ProviderAssemblyRecord
Returns the “default value” for a type. Read more
impl Eq for ProviderAssemblyRecord
Sourceimpl Hash for ProviderAssemblyRecord
impl Hash for ProviderAssemblyRecord
Sourceimpl Message for ProviderAssemblyRecord
impl Message for ProviderAssemblyRecord
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProviderAssemblyRecord
impl PartialEq for ProviderAssemblyRecord
impl StructuralPartialEq for ProviderAssemblyRecord