pub struct ProviderPhysicalRange {
pub pack_id: Vec<u8>,
pub object_etag: String,
pub offset: u64,
pub length: u64,
pub record_set_commitment: Vec<u8>,
}Expand description
A physical R2 range exactly tiled by independently hashed encoded records. record_set_commitment is a metadata commitment over pack identity, offset, length and ordered encoded record digests; it is not a hash of range bytes.
Fields
pack_id: Vec<u8>object_etag: Stringoffset: u64length: u64record_set_commitment: Vec<u8>Trait Implementations
Sourceimpl Clone for ProviderPhysicalRange
impl Clone for ProviderPhysicalRange
Sourcefn clone(&self) -> ProviderPhysicalRange
fn clone(&self) -> ProviderPhysicalRange
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderPhysicalRange
impl Debug for ProviderPhysicalRange
Sourceimpl Default for ProviderPhysicalRange
impl Default for ProviderPhysicalRange
Sourcefn default() -> ProviderPhysicalRange
fn default() -> ProviderPhysicalRange
Returns the “default value” for a type. Read more
impl Eq for ProviderPhysicalRange
Sourceimpl Hash for ProviderPhysicalRange
impl Hash for ProviderPhysicalRange
Sourceimpl Message for ProviderPhysicalRange
impl Message for ProviderPhysicalRange
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProviderPhysicalRange
impl PartialEq for ProviderPhysicalRange
impl StructuralPartialEq for ProviderPhysicalRange