pub struct ProviderPlan {
pub extent_set_digest: Vec<u8>,
pub extents: Vec<ProviderExtent>,
pub challenge: Option<ProviderPlanChallenge>,
pub assembly_digest: Vec<u8>,
pub pack_header: Vec<u8>,
pub output_pack_length: u64,
pub records: Vec<ProviderAssemblyRecord>,
}Fields
extent_set_digest: Vec<u8>extents: Vec<ProviderExtent>challenge: Option<ProviderPlanChallenge>assembly_digest: Vec<u8>pack_header: Vec<u8>Canonical LMPK v4 header: 16 bytes, including the exact record count.
output_pack_length: u64Must equal 16 + sum(encoded record lengths) + the final 32-byte BLAKE3(header || ordered encoded record bytes) trailer.
records: Vec<ProviderAssemblyRecord>Trait Implementations
Sourceimpl Clone for ProviderPlan
impl Clone for ProviderPlan
Sourcefn clone(&self) -> ProviderPlan
fn clone(&self) -> ProviderPlan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderPlan
impl Debug for ProviderPlan
Sourceimpl Default for ProviderPlan
impl Default for ProviderPlan
Sourcefn default() -> ProviderPlan
fn default() -> ProviderPlan
Returns the “default value” for a type. Read more
Sourceimpl Message for ProviderPlan
impl Message for ProviderPlan
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProviderPlan
impl PartialEq for ProviderPlan
impl StructuralPartialEq for ProviderPlan