pub struct ProviderResult {
pub extent_set_digest: Vec<u8>,
pub assembly_digest: Vec<u8>,
pub verified_range_commitments: Vec<Vec<u8>>,
pub assembled_pack: Option<ObjectAddress>,
}Fields
extent_set_digest: Vec<u8>assembly_digest: Vec<u8>verified_range_commitments: Vec<Vec<u8>>Ordered metadata commitments for ranges actually verified by the client. This report never authorizes source publication or claims server truth.
assembled_pack: Option<ObjectAddress>Trait Implementations
Sourceimpl Clone for ProviderResult
impl Clone for ProviderResult
Sourcefn clone(&self) -> ProviderResult
fn clone(&self) -> ProviderResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProviderResult
impl Debug for ProviderResult
Sourceimpl Default for ProviderResult
impl Default for ProviderResult
Sourcefn default() -> ProviderResult
fn default() -> ProviderResult
Returns the “default value” for a type. Read more
impl Eq for ProviderResult
Sourceimpl Hash for ProviderResult
impl Hash for ProviderResult
Sourceimpl Message for ProviderResult
impl Message for ProviderResult
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProviderResult
impl PartialEq for ProviderResult
impl StructuralPartialEq for ProviderResult