pub struct ProvisionAccountRequest {
pub client_operation_id: String,
pub invitation_secret: Vec<u8>,
pub agent_public_key: Vec<u8>,
}Expand description
Invite-gated creation of an unclaimed human account. The independent root
slot stays empty. The agent proves its own key over this exact request using
principal:device-key:
Fields
client_operation_id: Stringinvitation_secret: Vec<u8>agent_public_key: Vec<u8>Trait Implementations
Sourceimpl Clone for ProvisionAccountRequest
impl Clone for ProvisionAccountRequest
Sourcefn clone(&self) -> ProvisionAccountRequest
fn clone(&self) -> ProvisionAccountRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProvisionAccountRequest
impl Debug for ProvisionAccountRequest
Sourceimpl Default for ProvisionAccountRequest
impl Default for ProvisionAccountRequest
Sourcefn default() -> ProvisionAccountRequest
fn default() -> ProvisionAccountRequest
Returns the “default value” for a type. Read more
impl Eq for ProvisionAccountRequest
Sourceimpl Hash for ProvisionAccountRequest
impl Hash for ProvisionAccountRequest
Sourceimpl Message for ProvisionAccountRequest
impl Message for ProvisionAccountRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ProvisionAccountRequest
impl PartialEq for ProvisionAccountRequest
impl StructuralPartialEq for ProvisionAccountRequest