pub struct PublicHandleRecord {
pub display_name: String,
pub handle: String,
pub primary_handle: String,
pub kind: i32,
pub verified: bool,
pub discriminator: String,
}Expand description
Public directory metadata contains no stable subject/account identifiers. ResolveResources supplies those only within an authorized resource scope.
Fields
display_name: Stringhandle: Stringprimary_handle: Stringkind: i32verified: booldiscriminator: StringImplementations
Sourceimpl PublicHandleRecord
impl PublicHandleRecord
Sourcepub fn kind(&self) -> HandleKind
pub fn kind(&self) -> HandleKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: HandleKind)
pub fn set_kind(&mut self, value: HandleKind)
Sets kind to the provided enum value.