pub struct ReadArtifactRequest {
pub artifact: Option<RecordRef>,
pub offset: u64,
pub length: u64,
pub budget: Option<ReadBudget>,
}Fields
artifact: Option<RecordRef>offset: u64length: u64budget: Option<ReadBudget>A retained raw artifact requires its own disclosure authorization. This does not export runtime secret values from the execution broker.