pub struct RefreshCheckoutRequest {
pub client_operation_id: String,
pub checkout: Option<CheckoutRef>,
pub expected_checkout_version: Vec<u8>,
pub expected_source: Option<RevisionRef>,
pub target: Option<RevisionRef>,
pub writer_lease_token: Vec<u8>,
}Fields
client_operation_id: Stringcheckout: Option<CheckoutRef>expected_checkout_version: Vec<u8>expected_source: Option<RevisionRef>target: Option<RevisionRef>writer_lease_token: Vec<u8>Trait Implementations
Sourceimpl Clone for RefreshCheckoutRequest
impl Clone for RefreshCheckoutRequest
Sourcefn clone(&self) -> RefreshCheckoutRequest
fn clone(&self) -> RefreshCheckoutRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RefreshCheckoutRequest
impl Debug for RefreshCheckoutRequest
Sourceimpl Default for RefreshCheckoutRequest
impl Default for RefreshCheckoutRequest
Sourcefn default() -> RefreshCheckoutRequest
fn default() -> RefreshCheckoutRequest
Returns the “default value” for a type. Read more
impl Eq for RefreshCheckoutRequest
Sourceimpl Hash for RefreshCheckoutRequest
impl Hash for RefreshCheckoutRequest
Sourceimpl Message for RefreshCheckoutRequest
impl Message for RefreshCheckoutRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for RefreshCheckoutRequest
impl PartialEq for RefreshCheckoutRequest
impl StructuralPartialEq for RefreshCheckoutRequest