pub struct ReplicationReceipt {
pub accepted_operation_ids: Vec<Vec<u8>>,
pub pending_operation_ids: Vec<Vec<u8>>,
pub rejected: Vec<ReplicationRejection>,
pub accepted_frontiers: Vec<CausalFrontier>,
pub missing_objects: Vec<TransferObject>,
pub sharing_policy_version: Vec<u8>,
}Fields
accepted_operation_ids: Vec<Vec<u8>>Accepted means durably stored with accepted causal closure. A record merely received with missing parents is pending, and must not advance this frontier.
pending_operation_ids: Vec<Vec<u8>>rejected: Vec<ReplicationRejection>accepted_frontiers: Vec<CausalFrontier>missing_objects: Vec<TransferObject>Metadata admission is distinct from source/object availability.
sharing_policy_version: Vec<u8>Trait Implementations
Sourceimpl Clone for ReplicationReceipt
impl Clone for ReplicationReceipt
Sourcefn clone(&self) -> ReplicationReceipt
fn clone(&self) -> ReplicationReceipt
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReplicationReceipt
impl Debug for ReplicationReceipt
Sourceimpl Default for ReplicationReceipt
impl Default for ReplicationReceipt
Sourcefn default() -> ReplicationReceipt
fn default() -> ReplicationReceipt
Returns the “default value” for a type. Read more
Sourceimpl Message for ReplicationReceipt
impl Message for ReplicationReceipt
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ReplicationReceipt
impl PartialEq for ReplicationReceipt
impl StructuralPartialEq for ReplicationReceipt