pub struct Requirement {
pub kind: i32,
pub subject: Option<EntityRef>,
pub policy: Option<RecordRef>,
pub policy_version: Vec<u8>,
pub explanation: String,
pub recovery_method: String,
}Fields
kind: i32subject: Option<EntityRef>policy: Option<RecordRef>policy_version: Vec<u8>explanation: Stringrecovery_method: StringCanonical typed RPC route; advice never grants authority or executes it.
Implementations
Sourceimpl Requirement
impl Requirement
Sourcepub fn kind(&self) -> RequirementKind
pub fn kind(&self) -> RequirementKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: RequirementKind)
pub fn set_kind(&mut self, value: RequirementKind)
Sets kind to the provided enum value.