pub struct ResolveInvitationRequest {
pub invitation: Option<RecordRef>,
pub redemption_secret: Vec<u8>,
}Expand description
Public capability preview. The invitation ID alone reveals nothing; the redemption secret is passed in the request body and never placed in a URL path or query. No recipient email or inviter identity is disclosed.
Fields
invitation: Option<RecordRef>redemption_secret: Vec<u8>Trait Implementations
Sourceimpl Clone for ResolveInvitationRequest
impl Clone for ResolveInvitationRequest
Sourcefn clone(&self) -> ResolveInvitationRequest
fn clone(&self) -> ResolveInvitationRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolveInvitationRequest
impl Debug for ResolveInvitationRequest
Sourceimpl Default for ResolveInvitationRequest
impl Default for ResolveInvitationRequest
Sourcefn default() -> ResolveInvitationRequest
fn default() -> ResolveInvitationRequest
Returns the “default value” for a type. Read more
impl Eq for ResolveInvitationRequest
Sourceimpl Hash for ResolveInvitationRequest
impl Hash for ResolveInvitationRequest
Sourceimpl Message for ResolveInvitationRequest
impl Message for ResolveInvitationRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ResolveInvitationRequest
impl PartialEq for ResolveInvitationRequest
impl StructuralPartialEq for ResolveInvitationRequest