pub struct ResourceTransferHandoff {
pub format_version: u32,
pub resource_uuid: Vec<u8>,
pub transfer_sequence: u64,
pub source_owner_uuid: Vec<u8>,
pub source_owner_key_state_hash: Vec<u8>,
pub destination_owner_uuid: Vec<u8>,
pub destination_owner_key_state_hash: Vec<u8>,
pub nonce: Vec<u8>,
}Expand description
Canonical source offer for an atomic resource ownership re-anchor. canonical_resource_transfer_handoff_v1 encodes fields 1 through 8 in field order using fixed-width big-endian integers and length-prefixed byte strings. UUIDs are exactly 16 bytes, state hashes and nonce are exactly 32 bytes.
Fields
format_version: u32Exactly 1.
resource_uuid: Vec<u8>Stable 16-byte resource/spool UUID; transfer never changes it.
transfer_sequence: u64Exactly the previously committed transfer sequence plus one.
source_owner_uuid: Vec<u8>source_owner_key_state_hash: Vec<u8>destination_owner_uuid: Vec<u8>destination_owner_key_state_hash: Vec<u8>nonce: Vec<u8>Trait Implementations
Sourceimpl Clone for ResourceTransferHandoff
impl Clone for ResourceTransferHandoff
Sourcefn clone(&self) -> ResourceTransferHandoff
fn clone(&self) -> ResourceTransferHandoff
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceTransferHandoff
impl Debug for ResourceTransferHandoff
Sourceimpl Default for ResourceTransferHandoff
impl Default for ResourceTransferHandoff
Sourcefn default() -> ResourceTransferHandoff
fn default() -> ResourceTransferHandoff
Returns the “default value” for a type. Read more
impl Eq for ResourceTransferHandoff
Sourceimpl Hash for ResourceTransferHandoff
impl Hash for ResourceTransferHandoff
Sourceimpl Message for ResourceTransferHandoff
impl Message for ResourceTransferHandoff
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ResourceTransferHandoff
impl PartialEq for ResourceTransferHandoff
impl StructuralPartialEq for ResourceTransferHandoff