pub struct SearchDomainStatus {
pub domain: i32,
pub coverage: i32,
pub supported_modes: Vec<i32>,
}Expand description
Per-domain readiness is independent of result count and hidden matches. An unavailable index is not represented as an empty, complete result set.
Fields
domain: i32coverage: i32supported_modes: Vec<i32>Implementations
Sourceimpl SearchDomainStatus
impl SearchDomainStatus
Sourcepub fn domain(&self) -> SearchDomain
pub fn domain(&self) -> SearchDomain
Returns the enum value of domain, or the default if the field is set to an invalid enum value.
Sourcepub fn set_domain(&mut self, value: SearchDomain)
pub fn set_domain(&mut self, value: SearchDomain)
Sets domain to the provided enum value.
Sourcepub fn coverage(&self) -> Coverage
pub fn coverage(&self) -> Coverage
Returns the enum value of coverage, or the default if the field is set to an invalid enum value.
Sourcepub fn set_coverage(&mut self, value: Coverage)
pub fn set_coverage(&mut self, value: Coverage)
Sets coverage to the provided enum value.
Sourcepub fn supported_modes(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Mode>> ⓘ
pub fn supported_modes( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Mode>> ⓘ
Returns an iterator which yields the valid enum values contained in supported_modes.
Sourcepub fn push_supported_modes(&mut self, value: Mode)
pub fn push_supported_modes(&mut self, value: Mode)
Appends the provided enum value to supported_modes.