pub struct SemanticIndexLimits {
pub max_nodes: u32,
pub max_bytes: u64,
pub max_depth: u32,
}Expand description
Hard ingestion ceilings, independently of general source-transfer budgets. Absent on Ready means client SemanticIndex ingestion is unsupported. A supporting endpoint advertises positive limits no greater than 100000 nodes, 67108864 decoded bytes and depth 64. See code-navigation.md for accounting.
Fields
max_nodes: u32max_bytes: u64max_depth: u32Trait Implementations
Sourceimpl Clone for SemanticIndexLimits
impl Clone for SemanticIndexLimits
Sourcefn clone(&self) -> SemanticIndexLimits
fn clone(&self) -> SemanticIndexLimits
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for SemanticIndexLimits
Sourceimpl Debug for SemanticIndexLimits
impl Debug for SemanticIndexLimits
Sourceimpl Default for SemanticIndexLimits
impl Default for SemanticIndexLimits
Sourcefn default() -> SemanticIndexLimits
fn default() -> SemanticIndexLimits
Returns the “default value” for a type. Read more
impl Eq for SemanticIndexLimits
Sourceimpl Hash for SemanticIndexLimits
impl Hash for SemanticIndexLimits
Sourceimpl Message for SemanticIndexLimits
impl Message for SemanticIndexLimits
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SemanticIndexLimits
impl PartialEq for SemanticIndexLimits
impl StructuralPartialEq for SemanticIndexLimits