pub struct SignedPolicyMergeRule {
pub setting_key: String,
pub semantics: i32,
}Fields
setting_key: StringCanonical field name on SignedSpoolPolicy (“revoked_key_ids”, “max_audience”).
semantics: i32Implementations
Sourceimpl SignedPolicyMergeRule
impl SignedPolicyMergeRule
Sourcepub fn semantics(&self) -> SignedPolicyMergeSemantics
pub fn semantics(&self) -> SignedPolicyMergeSemantics
Returns the enum value of semantics, or the default if the field is set to an invalid enum value.
Sourcepub fn set_semantics(&mut self, value: SignedPolicyMergeSemantics)
pub fn set_semantics(&mut self, value: SignedPolicyMergeSemantics)
Sets semantics to the provided enum value.