pub struct SpoolCreationStatement {
pub format_version: u32,
pub genesis_digest: Vec<u8>,
pub account_uuid: Vec<u8>,
pub owner_state_hash: Vec<u8>,
pub owner_sequence: u64,
pub creator_key: Option<AuthorizationVerificationKey>,
pub parent_spool_uuid: Vec<u8>,
pub parent_path_segments: Vec<String>,
pub name: String,
pub created_at_unix_seconds: i64,
}Expand description
A creator’s statement of exact intended creation. created_at is NOT an admission timestamp. Only actual current admission or independently retained accepted evidence establishes whether this creation was permitted then. Canonical v1 fields follow tag order; domain “heddle-spool-creation-v1”.
Fields
format_version: u32genesis_digest: Vec<u8>SHA-256(“heddle-spool-owner-genesis-v1” || canonical genesis fields 1,2).
account_uuid: Vec<u8>owner_state_hash: Vec<u8>owner_sequence: u64creator_key: Option<AuthorizationVerificationKey>parent_spool_uuid: Vec<u8>Empty only for account-root creation.
parent_path_segments: Vec<String>name: Stringcreated_at_unix_seconds: i64Trait Implementations
Sourceimpl Clone for SpoolCreationStatement
impl Clone for SpoolCreationStatement
Sourcefn clone(&self) -> SpoolCreationStatement
fn clone(&self) -> SpoolCreationStatement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SpoolCreationStatement
impl Debug for SpoolCreationStatement
Sourceimpl Default for SpoolCreationStatement
impl Default for SpoolCreationStatement
Sourcefn default() -> SpoolCreationStatement
fn default() -> SpoolCreationStatement
Returns the “default value” for a type. Read more
impl Eq for SpoolCreationStatement
Sourceimpl Hash for SpoolCreationStatement
impl Hash for SpoolCreationStatement
Sourceimpl Message for SpoolCreationStatement
impl Message for SpoolCreationStatement
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SpoolCreationStatement
impl PartialEq for SpoolCreationStatement
impl StructuralPartialEq for SpoolCreationStatement