pub struct SupportAccessRecord {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub support_principal_id: String,
pub role: i32,
pub expires_at: Option<Timestamp>,
pub revoked: bool,
}Fields
ref: Option<RecordRef>version: Vec<u8>support_principal_id: Stringrole: i32expires_at: Option<Timestamp>revoked: boolUnrevoked support-access on this spool or on an ancestor that reaches this spool is admitted to AUDIENCE_MEMBERS. Not a GrantRecord/MemberRecord on the wire; writes go through SetSupportAccess, not PutGrant.
Implementations
Sourceimpl SupportAccessRecord
impl SupportAccessRecord
Sourcepub fn role(&self) -> ResourceRole
pub fn role(&self) -> ResourceRole
Returns the enum value of role, or the default if the field is set to an invalid enum value.
Sourcepub fn set_role(&mut self, value: ResourceRole)
pub fn set_role(&mut self, value: ResourceRole)
Sets role to the provided enum value.