pub struct TransferReady {Show 16 fields
pub endpoint: Option<EndpointRef>,
pub thread: Option<ThreadRef>,
pub current: Option<RevisionRef>,
pub current_version: Vec<u8>,
pub owner_genesis: Option<SignedSpoolOwnerGenesis>,
pub have: Vec<TransferObject>,
pub need: Vec<TransferObject>,
pub checkpoint: Option<TransferCheckpoint>,
pub budget: Option<ReadBudget>,
pub full_closure_available: bool,
pub missing: Vec<TransferObject>,
pub advertised_threads: Vec<ThreadOverview>,
pub page: Option<PageInfo>,
pub packs: Vec<PackExtent>,
pub ownership: Option<OwnerState>,
pub thread_genesis: Option<ThreadGenesisRecord>,
}Fields
endpoint: Option<EndpointRef>thread: Option<ThreadRef>current: Option<RevisionRef>current_version: Vec<u8>owner_genesis: Option<SignedSpoolOwnerGenesis>have: Vec<TransferObject>need: Vec<TransferObject>checkpoint: Option<TransferCheckpoint>budget: Option<ReadBudget>full_closure_available: boolmissing: Vec<TransferObject>advertised_threads: Vec<ThreadOverview>page: Option<PageInfo>packs: Vec<PackExtent>Exact whole artifacts selected for this download, in transmission order. Chunk offsets/lengths must stay inside these independently hashed extents.
ownership: Option<OwnerState>Clone verifies owner history and installs the original Thread genesis before materializing source. Neither identity is minted by the receiver.
thread_genesis: Option<ThreadGenesisRecord>Trait Implementations
Sourceimpl Clone for TransferReady
impl Clone for TransferReady
Sourcefn clone(&self) -> TransferReady
fn clone(&self) -> TransferReady
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransferReady
impl Debug for TransferReady
Sourceimpl Default for TransferReady
impl Default for TransferReady
Sourcefn default() -> TransferReady
fn default() -> TransferReady
Returns the “default value” for a type. Read more
Sourceimpl Message for TransferReady
impl Message for TransferReady
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for TransferReady
impl PartialEq for TransferReady
impl StructuralPartialEq for TransferReady