pub struct WorkspacePages {
pub spools: Option<PageRequest>,
pub threads: Option<PageRequest>,
pub attention: Option<PageRequest>,
pub operations: Option<PageRequest>,
pub devices: Option<PageRequest>,
pub bookmarks: Option<PageRequest>,
}Fields
spools: Option<PageRequest>threads: Option<PageRequest>attention: Option<PageRequest>operations: Option<PageRequest>devices: Option<PageRequest>bookmarks: Option<PageRequest>Trait Implementations
Sourceimpl Clone for WorkspacePages
impl Clone for WorkspacePages
Sourcefn clone(&self) -> WorkspacePages
fn clone(&self) -> WorkspacePages
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for WorkspacePages
impl Debug for WorkspacePages
Sourceimpl Default for WorkspacePages
impl Default for WorkspacePages
Sourcefn default() -> WorkspacePages
fn default() -> WorkspacePages
Returns the “default value” for a type. Read more
impl Eq for WorkspacePages
Sourceimpl Hash for WorkspacePages
impl Hash for WorkspacePages
Sourceimpl Message for WorkspacePages
impl Message for WorkspacePages
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for WorkspacePages
impl PartialEq for WorkspacePages
impl StructuralPartialEq for WorkspacePages