pub struct BehaviorOperation {
pub id: String,
pub symbol_address: String,
pub semantic_hash: Vec<u8>,
pub source: Option<BehaviorSource>,
pub provenance: i32,
}Fields
id: Stringsymbol_address: Stringsemantic_hash: Vec<u8>source: Option<BehaviorSource>provenance: i32Implementations
Sourceimpl BehaviorOperation
impl BehaviorOperation
Sourcepub fn provenance(&self) -> BehaviorProvenance
pub fn provenance(&self) -> BehaviorProvenance
Returns the enum value of provenance, or the default if the field is set to an invalid enum value.
Sourcepub fn set_provenance(&mut self, value: BehaviorProvenance)
pub fn set_provenance(&mut self, value: BehaviorProvenance)
Sets provenance to the provided enum value.