pub struct CaptureSummary {
pub revision: Option<RevisionRef>,
pub thread: Option<ThreadRef>,
pub summary: String,
pub changed_files: u64,
pub principal_id: String,
pub agent_id: String,
pub captured_at: Option<Timestamp>,
}Fields
revision: Option<RevisionRef>thread: Option<ThreadRef>summary: Stringchanged_files: u64principal_id: Stringagent_id: Stringcaptured_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for CaptureSummary
impl Clone for CaptureSummary
Sourcefn clone(&self) -> CaptureSummary
fn clone(&self) -> CaptureSummary
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CaptureSummary
impl Debug for CaptureSummary
Sourceimpl Default for CaptureSummary
impl Default for CaptureSummary
Sourcefn default() -> CaptureSummary
fn default() -> CaptureSummary
Returns the “default value” for a type. Read more
impl Eq for CaptureSummary
Sourceimpl Hash for CaptureSummary
impl Hash for CaptureSummary
Sourceimpl Message for CaptureSummary
impl Message for CaptureSummary
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for CaptureSummary
impl PartialEq for CaptureSummary
impl StructuralPartialEq for CaptureSummary