pub struct NotificationRule {
pub kind: String,
pub spool: Option<SpoolRef>,
pub actor_origin: String,
pub channel: i32,
pub delivery: i32,
}Fields
kind: Stringspool: Option<SpoolRef>actor_origin: Stringchannel: i32delivery: i32Implementations
Sourceimpl NotificationRule
impl NotificationRule
Sourcepub fn channel(&self) -> Channel
pub fn channel(&self) -> Channel
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: Channel)
pub fn set_channel(&mut self, value: Channel)
Sets channel to the provided enum value.
Sourcepub fn delivery(&self) -> Delivery
pub fn delivery(&self) -> Delivery
Returns the enum value of delivery, or the default if the field is set to an invalid enum value.
Sourcepub fn set_delivery(&mut self, value: Delivery)
pub fn set_delivery(&mut self, value: Delivery)
Sets delivery to the provided enum value.