pub struct SessionRecord {
pub ref: Option<RecordRef>,
pub version: Vec<u8>,
pub endpoint: Option<EndpointRef>,
pub expires_at: Option<Timestamp>,
pub revoked: bool,
pub issued_at: Option<Timestamp>,
pub last_used_at: Option<Timestamp>,
pub user_agent: String,
pub ip_address: String,
pub is_current: bool,
}Fields
ref: Option<RecordRef>version: Vec<u8>Opaque version of durable authorization state, usable directly for revoke. Serving endpoint and viewer-specific metadata do not affect this version.
endpoint: Option<EndpointRef>expires_at: Option<Timestamp>revoked: boolissued_at: Option<Timestamp>last_used_at: Option<Timestamp>user_agent: Stringip_address: Stringis_current: boolTrait Implementations
Sourceimpl Clone for SessionRecord
impl Clone for SessionRecord
Sourcefn clone(&self) -> SessionRecord
fn clone(&self) -> SessionRecord
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionRecord
impl Debug for SessionRecord
Sourceimpl Default for SessionRecord
impl Default for SessionRecord
Sourcefn default() -> SessionRecord
fn default() -> SessionRecord
Returns the “default value” for a type. Read more
impl Eq for SessionRecord
Sourceimpl Hash for SessionRecord
impl Hash for SessionRecord
Sourceimpl Message for SessionRecord
impl Message for SessionRecord
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SessionRecord
impl PartialEq for SessionRecord
impl StructuralPartialEq for SessionRecord