pub struct TransferObject {
pub address: Option<ObjectAddress>,
pub kind: String,
pub facet: i32,
pub size: u64,
pub availability: i32,
}Fields
address: Option<ObjectAddress>kind: Stringfacet: i32size: u64availability: i32Implementations
Sourceimpl TransferObject
impl TransferObject
Sourcepub fn facet(&self) -> SharedFacet
pub fn facet(&self) -> SharedFacet
Returns the enum value of facet, or the default if the field is set to an invalid enum value.
Sourcepub fn set_facet(&mut self, value: SharedFacet)
pub fn set_facet(&mut self, value: SharedFacet)
Sets facet to the provided enum value.
Sourcepub fn availability(&self) -> Coverage
pub fn availability(&self) -> Coverage
Returns the enum value of availability, or the default if the field is set to an invalid enum value.
Sourcepub fn set_availability(&mut self, value: Coverage)
pub fn set_availability(&mut self, value: Coverage)
Sets availability to the provided enum value.